@@ -3,17 +3,6 @@ package Geo::Coder::GooglePlaces;
 use strict;
 use warnings;
 use Geo::Coder::GooglePlaces::V3;
-our $VERSION = '0.02';
-
-sub new {
-    my ($self, %param) = @_;
-    delete $param{apiver};
-
-    return Geo::Coder::GooglePlaces::V3->new(%param);
-}
-
-1;
-__END__
 
 =head1 NAME
 
@@ -23,13 +12,26 @@ Geo::Coder::GooglePlaces - Google Maps Geocoding API
 
 Geo::Coder::GooglePlaces provides a geocoding functionality using Google Maps API.
 
-See L<Geo::Coder::GooglePlaces::V2> for V2 API usage.
+See L<Geo::Coder::GooglePlaces::V3> for usage.
 
-See L<Geo::Coder::GooglePlaces::V3> for V3 API usage.
+=cut
 
-B<Note that Google no longer supports the V2 API. Geo::Coder::GooglePlaces defaults 
-to the V3 API. The V2 interface is still here but any attempts to use it will
-fail since the V2 API service is no longer reachable.>
+our $VERSION = '0.03';
+
+=head1 SUBROUTINES/METHODS
+
+=head2 new
+
+See L<Geo::Coder::GooglePlaces::V3> for usage.
+
+=cut
+
+sub new {
+    my ($self, %param) = @_;
+    delete $param{apiver};
+
+    return Geo::Coder::GooglePlaces::V3->new(%param);
+}
 
 =head1 LICENSE
 
@@ -39,3 +41,5 @@ modify it under the same terms as Perl itself.
 See L<http://www.perl.com/perl/misc/Artistic.html>
 
 =cut
+
+1;
